<?php
use Bitrix\Main\Localization\Loc;
use Bitrix\Main\Config\Option;
IncludeModuleLangFile(__FILE__);

class bifit_kassa extends CModule
{
	var $MODULE_ID = 'bifit.kassa';
	var $MODULE_VERSION;
	var $MODULE_VERSION_DATE;
	var $MODULE_NAME;
	var $MODULE_DESCRIPTION;
	var $MODULE_PATH;
	var $PAYMENT_HANDLER_PATH;

	private $INSTALL_DIR;

	public function __construct()
	{
		$arModuleVersion = array();

		$path = str_replace("\\", "/", __FILE__);
		$path = substr($path, 0, strlen($path) - strlen("/install/index.php"));

		include $path . "/install/version.php";

		$this->MODULE_PATH = $path;
		$this->MODULE_NAME = GetMessage('BIFIT_MODULE_NAME');
		$this->MODULE_DESCRIPTION = GetMessage('BIFIT_MODULE_DESCRIPTION');
		$this->PARTNER_NAME = GetMessage('BIFIT_PARTNER_NAME');
		$this->PARTNER_URI = "https://kassa.bifit.com";
		$this->INSTALL_DIR = dirname(__FILE__);

		if (
			is_array($arModuleVersion) &&
			array_key_exists("VERSION", $arModuleVersion)
		) {
			$this->MODULE_VERSION = $arModuleVersion["VERSION"];
			$this->MODULE_VERSION_DATE = $arModuleVersion["VERSION_DATE"];
		}

		$ps_dir_path =
			strlen(COption::GetOptionString('sale', 'path2user_ps_files')) > 3
				? COption::GetOptionString('sale', 'path2user_ps_files')
				: '/bitrix/php_interface/include/sale_payment/';
		$this->PAYMENT_HANDLER_PATH =
			$_SERVER["DOCUMENT_ROOT"] .
			$ps_dir_path .
			str_replace(".", "_", $this->MODULE_ID) .
			"/";
	}

	function changeFiles($files)
	{
		foreach ($files as $file) {
			if ($file->isDot() === false) {
				$path_to_file = $file->getPathname();
				$file_contents = file_get_contents($path_to_file);
				$file_contents = str_replace(
					"{module_path}",
					$this->MODULE_ID,
					$file_contents
				);
				file_put_contents($path_to_file, $file_contents);
			}
		}
	}

	function InstallFiles($arParams = array())
	{
		CopyDirFiles(
			$this->MODULE_PATH . "/install/setup/handler_include",
			$this->PAYMENT_HANDLER_PATH,
			true,
			true
		);
		CopyDirFiles(
			$this->MODULE_PATH . "/install/setup/images/logo",
			$_SERVER['DOCUMENT_ROOT'] . '/bitrix/images/sale/sale_payments/'
		);
		$this->changeFiles(new DirectoryIterator($this->PAYMENT_HANDLER_PATH));
		$this->changeFiles(
			new DirectoryIterator($this->PAYMENT_HANDLER_PATH . 'template/')
		);
	}

	function UnInstallFiles()
	{
		$ps_dir_path =
			strlen(COption::GetOptionString('sale', 'path2user_ps_files')) > 3
				? COption::GetOptionString('sale', 'path2user_ps_files')
				: '/bitrix/php_interface/include/sale_payment/';
		DeleteDirFilesEx(
			$ps_dir_path . str_replace(".", "_", $this->MODULE_ID)
		);
	}

	public function DoInstall()
	{
		if (!$this->DoInstallDB()) {
			return false;
		}

		$this->InstallFiles();
		COption::SetOptionInt($this->MODULE_ID, "delete", false);
		$this->DoInstallFiles();
		COption::SetOptionString(
			$this->MODULE_ID,
			'server_url',
			'https://kassa.bifit.com'
		);
		RegisterModule($this->MODULE_ID);
		RegisterModuleDependences(
			"sale",
			"OnSaleStatusOrder",
			$this->MODULE_ID,
			"BifitKassa",
			"handleSaleOrderStatus"
		);
		RegisterModuleDependences(
			"sale",
			"OnSalePayOrder",
			$this->MODULE_ID,
			"BifitKassa",
			"handleSaleOrderPay"
		);
		RegisterModuleDependences(
			"sale",
			"OnOrderUpdate",
			$this->MODULE_ID,
			"BifitKassa",
			"handleOrderUpdate"
		);
		RegisterModuleDependences(
			"sale",
			"OnOrderAdd",
			$this->MODULE_ID,
			"BifitKassa",
			"handleOrderAdd"
		);

		return true;
	}

	public function DoUninstall()
	{
		COption::RemoveOption($this->MODULE_ID);
		UnRegisterModuleDependences(
			"sale",
			"OnSaleStatusOrder",
			$this->MODULE_ID,
			"BifitKassa",
			"handleSaleOrderStatus"
		);
		UnRegisterModuleDependences(
			"sale",
			"OnSalePayOrder",
			$this->MODULE_ID,
			"BifitKassa",
			"handleSaleOrderPay"
		);
		UnRegisterModuleDependences(
			"sale",
			"OnOrderUpdate",
			$this->MODULE_ID,
			"BifitKassa",
			"handleOrderUpdate"
		);
		UnRegisterModule($this->MODULE_ID);
		//$this->DoUninstallDB();
		$this->DoUninstallFiles();

		$this->UnInstallFiles();
		COption::SetOptionInt($this->MODULE_ID, "delete", true);
		DeleteDirFilesEx($this->MODULE_ID);

		return true;
	}

	public function DoInstallDB()
	{
		global $DB, $DBType, $APPLICATION;

		$errors = $DB->RunSQLBatch(
			sprintf('%s/db/%s/install.sql', $this->INSTALL_DIR, $DBType)
		);

		if (empty($errors)) {
			return true;
		}

		$APPLICATION->ThrowException(implode('', $errors));

		return false;
	}

	public function DoInstallFiles()
	{
		foreach (array('admin', 'tools') as $key) {
			CopyDirFiles(
				sprintf('%s/%s', $this->INSTALL_DIR, $key),
				sprintf('%s/bitrix/%s', $_SERVER["DOCUMENT_ROOT"], $key),
				true,
				true
			);
		}
	}

	public function DoUninstallDB()
	{
		global $DB, $DBType;

		$DB->RunSQLBatch(
			sprintf('%s/db/%s/uninstall.sql', $this->INSTALL_DIR, $DBType)
		);
	}

	public function DoUninstallFiles()
	{
		foreach (array('admin', 'tools') as $key) {
			DeleteDirFiles(
				sprintf('%s/%s', $this->INSTALL_DIR, $key),
				sprintf('%s/bitrix/%s', $_SERVER["DOCUMENT_ROOT"], $key)
			);
		}
	}
}
